@@ -18,7 +18,6 @@ from .cos_exception import CosServiceError
 
 SINGLE_UPLOAD_LENGTH = 5*1024*1024*1024  # 单次上传文件最大为5GB
 DEFAULT_CHUNK_SIZE = 1024*1024           # 计算MD5值时,文件单次读取的块大小为1MB
-LOGGING_UIN = 'id="qcs::cam::uin/100001001014:uin/100001001014"'
 # kwargs中params到http headers的映射
 maplist = {
             'ContentLength': 'Content-Length',
@@ -56,7 +55,9 @@ maplist = {
             'SSECustomerKey': 'x-cos-server-side-encryption-customer-key',
             'SSECustomerKeyMD5': 'x-cos-server-side-encryption-customer-key-MD5',
             'SSEKMSKeyId': 'x-cos-server-side-encryption-cos-kms-key-id',
-            'Referer': 'Referer'
+            'Referer': 'Referer',
+            'PicOperations': 'Pic-Operations',
+            'TrafficLimit': 'x-cos-traffic-limit',
            }
 
 
@@ -309,6 +310,8 @@ def get_copy_source_info(CopySource):
     endpoint = format_endpoint(endpoint, region)
     if 'Key' in CopySource:
         path = to_unicode(CopySource['Key'])
+        if path and path[0] == '/':
+            path = path[1:]
     else:
         raise CosClientError('CopySource Need Parameter Key')
     if 'VersionId' in CopySource:
@@ -377,7 +380,7 @@ def format_dict(data, key_lst):
         return data
     for key in key_lst:
         # 将dict转为list，保持一致
-        if key in data and isinstance(data[key], dict):
+        if key in data and (isinstance(data[key], dict) or isinstance(data[key], str)):
             lst = []
             lst.append(data[key])
             data[key] = lst
